#include "GaudiKernel/DeclareFactoryEntries.h"
#include "InDetSoftwareTutorial/InDetSoftwareTutorial.h"

using namespace InDet;

DECLARE_NAMESPACE_ALGORITHM_FACTORY(InDet, InDetSoftwareTutorial);//DECLARE_ALGORITHM_FACTORY( CBNT_VxPrimary );

DECLARE_FACTORY_ENTRIES( InDetSoftwareTutorial )
{
    DECLARE_NAMESPACE_ALGORITHM( InDet, InDetSoftwareTutorial );
};

