#--------------------------------------------------
# InDetPriVxFinder
#-------------------------------------------------
theApp.Dlls += [ "InDetSoftwareTutorial" ]
theApp.TopAlg += [ "InDet::InDetSoftwareTutorial/InDetSoftwareTutorial" ]

# uncomment the following lines here, or in your own top-level jobOptions, to modify the behaviour of the algorithm.
# InDetSoftwareTutorial = Algorithm( "InDetSoftwareTutorial" )
# InDetSoftwareTutorial.TracksName = "Tracks"
# InDetSoftwareTutorial.maxD0 = 0.25

