if test "${CMTROOT}" = ""; then
  CMTROOT=/afs/cern.ch/sw/contrib/CMT/v1r18p20051108; export CMTROOT
fi
. ${CMTROOT}/mgr/setup.sh
tempfile=`${CMTROOT}/mgr/cmt -quiet build temporary_name`
if test ! $? = 0 ; then tempfile=/tmp/cmt.$$; fi
${CMTROOT}/mgr/cmt cleanup -sh -pack=InDetSoftwareTutorial -version=InDetSoftwareTutorial-00-00-00 -path=/home/ryuichi/InDetRecExample/11.2.0/InnerDetector/InDetExample $* >${tempfile}; . ${tempfile}
/bin/rm -f ${tempfile}

