/**
\mainpage InDetSoftwareTutorial 

\section introduction Introduction:
InDetSoftwareTutorial is a package which contains a skeleton algorithm used as the basis for the tutorial explained in detail on this page:
https://uimon.cern.ch/twiki/bin/view/Atlas/UkInnerDetectorSoftwareTutorial

\section requirements Requirements
@include requirements

*/
