# echo "Setting InDetSoftwareTutorial InDetSoftwareTutorial-00-00-00 in /home/ryuichi/InDetRecExample/11.2.0/InnerDetector/InDetExample"

if ( $?CMTROOT == 0 ) then
  setenv CMTROOT /afs/cern.ch/sw/contrib/CMT/v1r18p20051108
endif
source ${CMTROOT}/mgr/setup.csh

set tempfile=`${CMTROOT}/mgr/cmt -quiet build temporary_name`
if $status != 0 then
  set tempfile=/tmp/cmt.$$
endif
${CMTROOT}/mgr/cmt setup -csh -pack=InDetSoftwareTutorial -version=InDetSoftwareTutorial-00-00-00 -path=/home/ryuichi/InDetRecExample/11.2.0/InnerDetector/InDetExample  -no_cleanup $* >${tempfile}; source ${tempfile}
/bin/rm -f ${tempfile}

